@@ -62,8 +62,12 @@ def run():
         console.setLevel(logging.WARN)
     else:
         console.setLevel(logging.INFO)
-        
-    console.setFormatter(logging.Formatter( ' %(message)s' + Style.RESET_ALL, '%H:%M:%S'))
+    
+    if os.environ.get("NOCOLOR"):
+        console.setFormatter(logging.Formatter( ' %(message)s' , '%H:%M:%S'))
+    else:
+        console.setFormatter(logging.Formatter( ' %(message)s' + Style.RESET_ALL, '%H:%M:%S'))
+
     logging.getLogger().addHandler(console)
 
     #
@@ -105,9 +109,9 @@ def run():
         pass
 
     if not args:
-        try:
+        if hasDefault():
             executeTask('default')
-        except:
+        else:
             logging.error("No tasks to execute. Please choose from: ")
             printTasks()
             sys.exit(1)
@@ -123,7 +127,6 @@ def main():
         run()
 
     except Exception as error:
-        os.system('pwd')
         console.fail("\n\n :puke: \n PUKE %s\n" % error)
         sys.exit(1)
         
